DataChunk

Struct DataChunk 

pub struct DataChunk {
    pub chunk_index: u64,
    pub logical_offset: u64,
    pub logical_size: usize,
    pub encoded_size: u64,
    pub encoding: DataChunkEncoding,
    pub corrupted: bool,
    pub data: Vec<u8>,
}
Decoded logical data chunk.

Fields

chunk_index: u64

Zero-based logical chunk index.

logical_offset: u64

Logical byte offset of the chunk.

logical_size: usize

Logical byte size of the decoded chunk.

encoded_size: u64

Encoded byte size as stored in the segment.

encoding: DataChunkEncoding

Encoding used by the stored chunk.

corrupted: bool

Whether the chunk was returned under a corruption-tolerant read policy.

data: Vec<u8>

Decoded chunk bytes.

Implementations

Source

impl DataChunk

pub fn is_corrupted(&self) -> bool

Returns whether this chunk was marked corrupted while reading.

pub fn read_buffer(&self, buffer: &mut [u8]) -> Result<usize>

Copies decoded chunk bytes into buffer.

pub fn write_buffer(&mut self, buffer: &[u8]) -> Result<usize>

Replaces this chunk with raw bytes from buffer.

Errors

Returns an error if the buffer length does not fit in EWF chunk metadata.