pub struct EwfMetadata {
pub case_number: Option<String>,
pub evidence_number: Option<String>,
pub examiner: Option<String>,
pub description: Option<String>,
pub notes: Option<String>,
pub acquisition_software: Option<String>,
pub acquisition_software_version: Option<String>,
pub os_version: Option<String>,
pub acquisition_date: Option<String>,
pub system_date: Option<String>,
pub password: Option<String>,
pub header_values: BTreeMap<String, String>,
}Expand description
Parsed case and acquisition metadata.
Fields
case_number: Option<String>Case number header value.
evidence_number: Option<String>Evidence number header value.
examiner: Option<String>Examiner name header value.
description: Option<String>Case description header value.
notes: Option<String>Notes header value.
acquisition_software: Option<String>Acquisition software name.
acquisition_software_version: Option<String>Acquisition software version.
os_version: Option<String>Acquisition operating system version.
acquisition_date: Option<String>Acquisition date header value.
system_date: Option<String>System date header value.
password: Option<String>Password header value, when present in metadata.
header_values: BTreeMap<String, String>Non-standard or otherwise unmapped header values.
Implementations
Sourceimpl EwfMetadata
impl EwfMetadata
Sourcepub fn copy_header_values_from(&mut self, source: &EwfMetadata)
pub fn copy_header_values_from(&mut self, source: &EwfMetadata)
Replaces this metadata with another metadata value.
Sourcepub fn header_value(&self, identifier: &str) -> Option<&str>
pub fn header_value(&self, identifier: &str) -> Option<&str>
Returns a header value by its EWF identifier.
Sourcepub fn header_value_with_date_format(
&self,
identifier: &str,
date_format: HeaderDateFormat,
) -> Option<Cow<'_, str>>
pub fn header_value_with_date_format( &self, identifier: &str, date_format: HeaderDateFormat, ) -> Option<Cow<'_, str>>
Returns a header value, applying date formatting for known date fields.
Sourcepub fn set_header_value(
&mut self,
identifier: &str,
value: impl Into<String>,
) -> Option<String>
pub fn set_header_value( &mut self, identifier: &str, value: impl Into<String>, ) -> Option<String>
Sets a header value by its EWF identifier and returns the previous value.
Sourcepub fn number_of_header_values(&self) -> usize
pub fn number_of_header_values(&self) -> usize
Returns the number of available header values.
Sourcepub fn header_value_identifier(&self, index: usize) -> Option<&str>
pub fn header_value_identifier(&self, index: usize) -> Option<&str>
Returns the header value identifier at a stable enumeration index.