SingleFileEntry

Struct SingleFileEntry 

pub struct SingleFileEntry {
Show 24 fields pub identifier: Option<u64>, pub file_entry_type: Option<SingleFileEntryType>, pub flags: Option<u32>, pub guid: Option<String>, pub name: Option<String>, pub short_name: Option<String>, pub size: Option<u64>, pub logical_offset: Option<i64>, pub physical_offset: Option<i64>, pub duplicate_data_offset: Option<i64>, pub source_identifier: Option<i32>, pub subject_identifier: Option<u32>, pub permission_group_index: Option<i32>, pub record_type: Option<u32>, pub creation_time: Option<i64>, pub modification_time: Option<i64>, pub access_time: Option<i64>, pub entry_modification_time: Option<i64>, pub deletion_time: Option<i64>, pub md5: Option<String>, pub sha1: Option<String>, pub extents: Vec<SingleFileExtent>, pub attributes: Vec<SingleFileAttribute>, pub children: Vec<SingleFileEntry>,
}
Entry in a logical single-file catalog.

Fields

identifier: Option<u64>

Entry identifier.

file_entry_type: Option<SingleFileEntryType>

Entry type.

flags: Option<u32>

Raw entry flags.

guid: Option<String>

Entry GUID.

name: Option<String>

Entry name.

short_name: Option<String>

Short entry name.

size: Option<u64>

Logical file size in bytes.

logical_offset: Option<i64>

Logical media offset for the entry data.

physical_offset: Option<i64>

Physical source offset for the entry data.

duplicate_data_offset: Option<i64>

Duplicate-data logical media offset.

source_identifier: Option<i32>

Identifier of the associated source record.

subject_identifier: Option<u32>

Identifier of the associated subject record.

permission_group_index: Option<i32>

Index of the associated permission group.

record_type: Option<u32>

Raw record type.

creation_time: Option<i64>

Creation timestamp.

modification_time: Option<i64>

Modification timestamp.

access_time: Option<i64>

Access timestamp.

entry_modification_time: Option<i64>

Entry metadata modification timestamp.

deletion_time: Option<i64>

Deletion timestamp.

md5: Option<String>

Entry MD5 hash string.

sha1: Option<String>

Entry SHA1 hash string.

extents: Vec<SingleFileExtent>

Data extents for the entry.

attributes: Vec<SingleFileAttribute>

Extended attributes for the entry.

children: Vec<SingleFileEntry>

Child entries.

Implementations

Source

impl SingleFileEntry

pub fn identifier(&self) -> Option<u64>

Returns the entry identifier.

pub fn entry_type(&self) -> Option<SingleFileEntryType>

Returns the entry type.

pub fn flags(&self) -> Option<u32>

Returns the raw entry flags.

pub fn guid(&self) -> Option<&str>

Returns the entry GUID.

pub fn media_data_offset(&self) -> Option<i64>

Returns the logical media offset for entry data.

pub fn media_data_size(&self) -> Option<u64>

Returns the entry data size in bytes.

pub fn physical_offset(&self) -> Option<i64>

Returns the physical source offset for entry data.

pub fn duplicate_media_data_offset(&self) -> Option<i64>

Returns the duplicate-data logical media offset.

pub fn source_identifier(&self) -> Option<i32>

Returns the associated source identifier.

pub fn subject_identifier(&self) -> Option<u32>

Returns the associated subject identifier.

pub fn permission_group_index(&self) -> Option<i32>

Returns the associated permission group index.

pub fn record_type(&self) -> Option<u32>

Returns the raw record type.

pub fn name(&self) -> Option<&str>

Returns the entry name.

pub fn short_name(&self) -> Option<&str>

Returns the short entry name.

pub fn size(&self) -> Option<u64>

Returns the entry size in bytes.

pub fn creation_time(&self) -> Option<i64>

Returns the creation timestamp.

pub fn modification_time(&self) -> Option<i64>

Returns the modification timestamp.

pub fn access_time(&self) -> Option<i64>

Returns the access timestamp.

pub fn entry_modification_time(&self) -> Option<i64>

Returns the entry metadata modification timestamp.

pub fn deletion_time(&self) -> Option<i64>

Returns the deletion timestamp.

pub fn md5_hash(&self) -> Option<&str>

Returns the entry MD5 hash string.

pub fn sha1_hash(&self) -> Option<&str>

Returns the entry SHA1 hash string.

pub fn number_of_sub_file_entries(&self) -> usize

Returns the number of child entries.

pub fn sub_file_entry(&self, index: usize) -> Option<&SingleFileEntry>

Returns a child entry by index.

pub fn sub_file_entry_by_name(&self, name: &str) -> Option<&SingleFileEntry>

Returns a child entry by name.

pub fn sub_file_entry_by_path( &self, path: &str, ) -> Result<Option<&SingleFileEntry>>

Returns a descendant entry by single-file path.

Errors

Returns an error if the path contains an empty entry name.

pub fn number_of_extents(&self) -> usize

Returns the number of data extents.

pub fn extent(&self, index: usize) -> Option<&SingleFileExtent>

Returns a data extent by index.

pub fn number_of_attributes(&self) -> usize

Returns the number of extended attributes.

pub fn attribute(&self, index: usize) -> Option<&SingleFileAttribute>

Returns an extended attribute by index.

pub fn child_by_name(&self, name: &str) -> Option<&SingleFileEntry>

Returns a direct child entry by name.

pub fn child_by_path(&self, path: &str) -> Result<Option<&SingleFileEntry>>

Returns a descendant entry by single-file path.

Errors

Returns an error if the path contains an empty entry name.