SingleFilesInfo

Struct SingleFilesInfo 

pub struct SingleFilesInfo {
    pub data_size: u64,
    pub root: SingleFileEntry,
    pub sources: Vec<SingleFileSource>,
    pub subjects: Vec<SingleFileSubject>,
    pub permission_groups: Vec<SingleFilePermissionGroup>,
}
Logical single-file catalog metadata.

Fields

data_size: u64

Byte size of the single-file data section.

root: SingleFileEntry

Root catalog entry.

sources: Vec<SingleFileSource>

Source records.

subjects: Vec<SingleFileSubject>

Subject records.

permission_groups: Vec<SingleFilePermissionGroup>

Permission groups.

Implementations

Source

impl SingleFilesInfo

pub fn entry_by_path(&self, path: &str) -> Result<Option<&SingleFileEntry>>

Returns the catalog entry at a single-file path.

Errors

Returns an error if the path contains an empty entry name.

pub fn source_by_identifier(&self, identifier: i32) -> Option<&SingleFileSource>

Returns a source record by its source identifier.

pub fn source_by_index(&self, index: i32) -> Option<&SingleFileSource>

Returns a source record by its source table index.

pub fn source_for_entry( &self, entry: &SingleFileEntry, ) -> Option<&SingleFileSource>

Returns the source record associated with a catalog entry.

pub fn subject_by_identifier( &self, identifier: u32, ) -> Option<&SingleFileSubject>

Returns a subject record by its subject identifier.

pub fn subject_for_entry( &self, entry: &SingleFileEntry, ) -> Option<&SingleFileSubject>

Returns the subject record associated with a catalog entry.

pub fn number_of_permission_groups(&self) -> usize

Returns the number of permission groups.

pub fn permission_group_by_index( &self, index: i32, ) -> Option<&SingleFilePermissionGroup>

Returns a permission group by its table index.

pub fn permission_group_for_entry( &self, entry: &SingleFileEntry, ) -> Option<&SingleFilePermissionGroup>

Returns the permission group associated with a catalog entry.

pub fn access_control_entries_for_entry( &self, entry: &SingleFileEntry, ) -> &[SingleFilePermission]

Returns access-control entries associated with a catalog entry.

pub fn number_of_access_control_entries_for_entry( &self, entry: &SingleFileEntry, ) -> usize

Returns the number of access-control entries for a catalog entry.

pub fn access_control_entry_for_entry( &self, entry: &SingleFileEntry, index: usize, ) -> Option<&SingleFilePermission>

Returns one access-control entry for a catalog entry by index.