WriteHashes

Struct WriteHashes 

pub struct WriteHashes {
    pub md5: Option<[u8; 16]>,
    pub sha1: Option<[u8; 20]>,
    pub hash_values: BTreeMap<String, String>,
}
Hash values configured for writer output.

Fields

md5: Option<[u8; 16]>

MD5 hash bytes.

sha1: Option<[u8; 20]>

SHA1 hash bytes.

hash_values: BTreeMap<String, String>

Hash strings keyed by hash identifier.

Implementations

Source

impl WriteHashes

pub fn copy_hash_values_from_stored_hashes(&mut self, hashes: &StoredHashes)

Copies stored hash values from an image hash collection.

pub fn hash_value(&self, identifier: &str) -> Option<&str>

Returns a hash string by identifier.

pub fn set_hash_value( &mut self, identifier: impl Into<String>, value: impl Into<String>, ) -> Result<Option<String>>

Sets a hash string by identifier and returns the previous value.

MD5 and SHA1 values are also parsed into typed byte arrays.

Errors

Returns an error if an MD5 or SHA1 value is not valid hexadecimal of the required length.

pub fn number_of_hash_values(&self) -> usize

Returns the number of configured hash strings.

pub fn hash_value_identifier(&self, index: usize) -> Option<&str>

Returns a hash identifier by enumeration index.