pub struct OpenOptions {
pub strictness: OpenStrictness,
pub chunk_cache_size: usize,
pub read_zero_chunk_on_error: bool,
pub header_codepage: HeaderCodepage,
pub header_values_date_format: HeaderDateFormat,
pub maximum_open_handles: Option<usize>,
}Expand description
Options that control how an image is opened and read.
Fields
strictness: OpenStrictnessStructural validation policy.
chunk_cache_size: usizeNumber of decoded chunks retained in the read cache.
read_zero_chunk_on_error: boolReturn zero-filled chunk data when a chunk checksum fails.
header_codepage: HeaderCodepageCodepage used to decode EWF1 header values.
header_values_date_format: HeaderDateFormatDate formatting applied when returning header date values.
maximum_open_handles: Option<usize>Maximum number of simultaneously open segment handles.