#[non_exhaustive]pub struct ReaderStatistics { /* private fields */ }Expand description
Cumulative performance counters for one shared EWF image reader.
Collection is opt-in through crate::OpenOptions::with_reader_statistics.
Cloned crate::Image values and their cursors share the same counters.
Implementations
Sourceimpl ReaderStatistics
impl ReaderStatistics
Sourcepub fn cursors_created(&self) -> u64
pub fn cursors_created(&self) -> u64
Returns the number of logical-media and single-file cursors created.
Sourcepub fn segment_parses(&self) -> u64
pub fn segment_parses(&self) -> u64
Returns the number of segment metadata parses performed while opening.
Sourcepub fn segment_handle_opens(&self) -> u64
pub fn segment_handle_opens(&self) -> u64
Returns the number of segment handles opened for the first time.
Sourcepub fn segment_handle_reopens(&self) -> u64
pub fn segment_handle_reopens(&self) -> u64
Returns the number of previously evicted segment handles reopened.
Sourcepub fn table_checksum_bytes(&self) -> u64
pub fn table_checksum_bytes(&self) -> u64
Returns the table-entry bytes processed for checksum validation.
Sourcepub fn table_checksum_nanos(&self) -> u64
pub fn table_checksum_nanos(&self) -> u64
Returns nanoseconds spent validating table-entry checksums.
Sourcepub fn chunk_cache_hits(&self) -> u64
pub fn chunk_cache_hits(&self) -> u64
Returns decoded chunk-cache hits.
Sourcepub fn chunk_cache_misses(&self) -> u64
pub fn chunk_cache_misses(&self) -> u64
Returns decoded chunk-cache misses.
Sourcepub fn table_page_cache_hits(&self) -> u64
pub fn table_page_cache_hits(&self) -> u64
Returns table-entry page-cache hits.
Sourcepub fn table_page_cache_misses(&self) -> u64
pub fn table_page_cache_misses(&self) -> u64
Returns table-entry page-cache misses.
Sourcepub fn encoded_bytes_read(&self) -> u64
pub fn encoded_bytes_read(&self) -> u64
Returns encoded chunk bytes read from segment files.
Sourcepub fn decoded_bytes(&self) -> u64
pub fn decoded_bytes(&self) -> u64
Returns decoded logical chunk bytes produced.
Sourcepub fn decompression_nanos(&self) -> u64
pub fn decompression_nanos(&self) -> u64
Returns nanoseconds spent decompressing chunks.
Sourcepub fn saturating_delta(self, earlier: Self) -> Self
pub fn saturating_delta(self, earlier: Self) -> Self
Returns a field-wise saturating delta from an earlier snapshot.