pub struct SingleFileCursor { /* private fields */ }Expand description
Seekable cursor over one logical single-file catalog entry.
Implementations
Sourceimpl SingleFileCursor
impl SingleFileCursor
Sourcepub fn offset(&self) -> u64
pub fn offset(&self) -> u64
Alias for SingleFileCursor::position.
Sourcepub fn read_buffer(&mut self, buf: &mut [u8]) -> Result<usize>
pub fn read_buffer(&mut self, buf: &mut [u8]) -> Result<usize>
Reads bytes at the current single-file position and advances.
Errors
Returns an error if the underlying single-file read fails or the cursor position would overflow.
Sourcepub fn read_buffer_at_offset(
&mut self,
buf: &mut [u8],
offset: u64,
) -> Result<usize>
pub fn read_buffer_at_offset( &mut self, buf: &mut [u8], offset: u64, ) -> Result<usize>
Seeks to offset, reads into buf, and advances by the bytes read.
Errors
Returns the same errors as SingleFileCursor::read_buffer.