pub struct StoredHashes {
pub md5: Option<[u8; 16]>,
pub sha1: Option<[u8; 20]>,
pub hash_values: BTreeMap<String, String>,
}Expand description
Stored hash values parsed from an image.
Fields
md5: Option<[u8; 16]>Parsed MD5 hash bytes, if a valid MD5 value was stored.
sha1: Option<[u8; 20]>Parsed SHA1 hash bytes, if a valid SHA1 value was stored.
hash_values: BTreeMap<String, String>Stored hash strings keyed by hash identifier.
Implementations
Sourceimpl StoredHashes
impl StoredHashes
Sourcepub fn hash_value(&self, identifier: &str) -> Option<&str>
pub fn hash_value(&self, identifier: &str) -> Option<&str>
Returns a stored hash value by identifier.
Sourcepub fn set_hash_value(
&mut self,
identifier: impl Into<String>,
value: impl Into<String>,
) -> Option<String>
pub fn set_hash_value( &mut self, identifier: impl Into<String>, value: impl Into<String>, ) -> Option<String>
Sets a stored hash value and returns the previous string value.
Sourcepub fn number_of_hash_values(&self) -> usize
pub fn number_of_hash_values(&self) -> usize
Returns the number of stored hash values.
Sourcepub fn hash_value_identifier(&self, index: usize) -> Option<&str>
pub fn hash_value_identifier(&self, index: usize) -> Option<&str>
Returns the hash identifier at a stable enumeration index.